@@ -4,5 +4,5 @@ from .basecontainer import BaseContainer
 class Container(BaseContainer, Frame):
    _DEFAULT_STYLE = BaseContainer._defaultStyle()
    
-   def __init__(self, master = None, **kw):
+   def __init__(self, master, **kw):
       BaseContainer.__init__(self, master, padAllChildren = False, **kw)
